==> qgis_3.22.16+dfsg.orig.tar.xz: qgis-3.22.16/src/3d/qgsabstract3dengine.cpp <==
/***************************************************************************
  qgsabstract3dengine.cpp
  --------------------------------------
  Date                 : July 2018
  Copyright            : (C) 2018 by Martin Dobias
  Email                : wonder dot sk at gmail dot com
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qgsabstract3dengine.h"

#include "qgsshadowrenderingframegraph.h"

#include <Qt3DRender/QRenderCapture>
#include <Qt3DRender/QRenderSettings>

QgsAbstract3DEngine::QgsAbstract3DEngine( QObject *parent )
  : QObject( parent )
{

}

void QgsAbstract3DEngine::requestCaptureImage()
{
  Qt3DRender::QRenderCaptureReply *captureReply;
  captureReply = mFrameGraph->renderCapture()->requestCapture();
  // We need to change render policy to RenderPolicy::Always, since otherwise render capture node won't work
  this->renderSettings()->setRenderPolicy( Qt3DRender::QRenderSettings::RenderPolicy::Always );
  connect( captureReply, &Qt3DRender::QRenderCaptureReply::completed, this, [ = ]
  {
    emit imageCaptured( captureReply->image() );
    this->renderSettings()->setRenderPolicy( Qt3DRender::QRenderSettings::RenderPolicy::OnDemand );
    captureReply->deleteLater();
  } );
}

void QgsAbstract3DEngine::setRenderCaptureEnabled( bool enabled )
{
  mFrameGraph->setRenderCaptureEnabled( enabled );
}

bool QgsAbstract3DEngine::renderCaptureEnabled() const
{
  return mFrameGraph->renderCaptureEnabled();
}

==> qgis_3.40.8+dfsg.orig.tar.xz: qgis-3.40.8/src/3d/qgsabstract3dengine.cpp <==
/***************************************************************************
  qgsabstract3dengine.cpp
  --------------------------------------
  Date                 : July 2018
  Copyright            : (C) 2018 by Martin Dobias
  Email                : wonder dot sk at gmail dot com
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qgsabstract3dengine.h"
#include "moc_qgsabstract3dengine.cpp"

#include "qgsframegraph.h"

#include <Qt3DRender/QRenderCapture>
#include <Qt3DRender/QRenderSettings>

QgsAbstract3DEngine::QgsAbstract3DEngine( QObject *parent )
  : QObject( parent )
{
}

void QgsAbstract3DEngine::requestCaptureImage()
{
  Qt3DRender::QRenderCaptureReply *captureReply;
  captureReply = mFrameGraph->renderCapture()->requestCapture();

  connect( captureReply, &Qt3DRender::QRenderCaptureReply::completed, this, [=] {
    emit imageCaptured( captureReply->image() );
    captureReply->deleteLater();
  } );
}

void QgsAbstract3DEngine::requestDepthBufferCapture()
{
  Qt3DRender::QRenderCaptureReply *captureReply;
  captureReply = mFrameGraph->depthRenderCapture()->requestCapture();

  connect( captureReply, &Qt3DRender::QRenderCaptureReply::completed, this, [=] {
    emit depthBufferCaptured( captureReply->image() );
    captureReply->deleteLater();
  } );
}

void QgsAbstract3DEngine::setRenderCaptureEnabled( bool enabled )
{
  mFrameGraph->setRenderCaptureEnabled( enabled );
}

bool QgsAbstract3DEngine::renderCaptureEnabled() const
{
  return mFrameGraph->renderCaptureEnabled();
}

void QgsAbstract3DEngine::dumpFrameGraphToConsole() const
{
  if ( mFrameGraph )
  {
    qDebug() << "FrameGraph:\n"
             << mFrameGraph->dumpFrameGraph();
    qDebug() << "SceneGraph:\n"
             << mFrameGraph->dumpSceneGraph();
  }
}

QString QgsAbstract3DEngine::dumpFrameGraph() const
{
  if ( mFrameGraph )
  {
    return mFrameGraph->dumpFrameGraph();
  }
  return QString();
}

QString QgsAbstract3DEngine::dumpSceneGraph() const
{
  if ( mFrameGraph )
  {
    return mFrameGraph->dumpSceneGraph();
  }
  return QString();
}
